@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Annotation.pm,v 2.0 2005/11/16 02:16:00 areibens Exp $
+#   $Id: Annotation.pm,v 2.1 2007/10/02 19:59:37 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Annotation;
@@ -44,7 +44,7 @@ BEGIN
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:00 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/10/02 19:59:37 $
 
     use utf8;
     use Encode qw(:all);
@@ -431,6 +431,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Annotation.pm,v $
+    Revision 2.1  2007/10/02 19:59:37  areibens
+    added movie annotation
+
     Revision 2.0  2005/11/16 02:16:00  areibens
     revision workaround for SF cvs import not to screw up CPAN
 
