@@ -21,18 +21,19 @@
 #   This specific module is licensed under the Perl Artistic License.
 #
 #
-#   $Id: Array.pm,v 1.5 2004/06/15 09:13:12 fredo Exp $
+#   $Id: Array.pm,v 2.0 2005/11/16 02:16:00 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Basic::PDF::Array;
 
 use strict;
 use vars qw(@ISA);
-# no warnings qw(uninitialized);
 
 use PDF::API2::Basic::PDF::Objind;
 @ISA = qw(PDF::API2::Basic::PDF::Objind);
 
+no warnings qw[ deprecated recursion uninitialized ];
+
 =head1 NAME
 
 PDF::API2::Basic::PDF::Array - Corresponds to a PDF array. Inherits from L<PDF::Objind>
