@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Text.pm,v 1.10 2005/06/17 19:44:02 fredo Exp $
+#   $Id: Text.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Content::Text;
@@ -43,7 +43,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Content);
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.10 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:02 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:04 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -72,6 +72,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Text.pm,v $
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
     Revision 1.10  2005/06/17 19:44:02  fredo
     fixed CPAN modulefile versioning (again)
 
