@@ -27,12 +27,13 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CIDFont.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
+#   $Id: CIDFont.pm,v 2.3 2007/03/17 20:38:50 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont;
 
-BEGIN {
+BEGIN 
+{
 
     use utf8;
     use Encode qw(:all);
@@ -40,7 +41,6 @@ BEGIN {
     use PDF::API2::Util;
     use PDF::API2::Basic::PDF::Utils;
     use PDF::API2::Resource::BaseFont;
-    use PDF::API2::IOString;
 
     use POSIX;
 
@@ -48,9 +48,9 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::BaseFont );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:04 $
-
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.3 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/03/17 20:38:50 $
 }
+
 no warnings qw[ deprecated recursion uninitialized ];
 
 =item $font = PDF::API2::Resource::CIDFont->new $pdf, $name
@@ -59,7 +59,8 @@ Returns a cid-font object. base class form all CID based fonts.
 
 =cut
 
-sub new {
+sub new 
+{
     my ($class,$pdf,$name,@opts) = @_;
     my %opts=();
     %opts=@opts if((scalar @opts)%2 == 0);
@@ -95,7 +96,8 @@ it needs an PDF::API2-object rather than a Text::PDF::File-object.
 
 =cut
 
-sub new_api {
+sub new_api 
+{
     my ($class,$api,@opts)=@_;
 
     my $obj=$class->new($api->{pdf},@opts);
@@ -113,16 +115,22 @@ sub cidByUni { return( $_[0]->data->{u2g}->{$_[1]} ); }
 
 sub cidByEnc { return( $_[0]->data->{e2g}->[$_[1]] ); }
 
-sub wxByCId {
+sub wxByCId 
+{
     my $self=shift @_;
     my $g=shift @_;
     my $w;
 
-    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g]) {
+    if(ref($self->data->{wx}) eq 'ARRAY' && defined $self->data->{wx}->[$g]) 
+    {
         $w = int($self->data->{wx}->[$g]);
-    } elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g}) {
+    } 
+    elsif(ref($self->data->{wx}) eq 'HASH' && defined $self->data->{wx}->{$g}) 
+    {
         $w = int($self->data->{wx}->{$g});
-    } else {
+    } 
+    else 
+    {
         $w = $self->missingwidth;
     }
 
@@ -132,15 +140,19 @@ sub wxByCId {
 sub wxByUni { return( $_[0]->wxByCId($_[0]->data->{u2g}->{$_[1]}) ); }
 sub wxByEnc { return( $_[0]->wxByCId($_[0]->data->{e2g}->[$_[1]]) ); }
 
-sub width {
+sub width 
+{
     my ($self,$text)=@_;
     return($self->width_cid($self->cidsByStr($text)));
 }
-sub width_cid {
+
+sub width_cid 
+{
     my ($self,$text)=@_;
     my $width=0;
     my $lastglyph=0;
-    foreach my $n (unpack('n*',$text)) {
+    foreach my $n (unpack('n*',$text)) 
+    {
         $width+=$self->wxByCId($n);
         if($self->{-dokern} && $self->haveKernPairs())
         {
@@ -161,7 +173,8 @@ Returns the cid-string from string based on the fonts encoding map.
 
 =cut
 
-sub _cidsByStr {
+sub _cidsByStr 
+{
     my ($self,$s)=@_;
     $s=pack('n*',map { $self->cidByEnc($_) } unpack('C*',$s));
     return($s);
@@ -215,22 +228,29 @@ sub textByStr
 
 sub textByStrKern 
 {
-    my ($self,$text,$size)=@_;
-    return($self->text_cid_kern($self->cidsByStr($text),$size));
+    my ($self,$text,$size,$ident)=@_;
+    return($self->text_cid_kern($self->cidsByStr($text),$size,$ident));
 }
 
 sub text 
 { 
-    my ($self,$text,$size)=@_;
+    my ($self,$text,$size,$ident)=@_;
     my $newtext=$self->textByStr($text);
     if(defined $size && $self->{-dokern})
     {
-        $newtext=$self->textByStrKern($text,$size);
+        $newtext=$self->textByStrKern($text,$size,$ident);
         return($newtext);
     }
     elsif(defined $size)
     {
-        return("$newtext Tj");
+        if(defined($ident) && $ident!=0)
+        {
+	        return("[ $ident $newtext ] TJ");
+        }
+        else
+        {
+	        return("$newtext Tj");
+        }        
     }
     else
     {
@@ -243,7 +263,8 @@ sub text_cid
     my ($self,$text,$size)=@_;
     if(UNIVERSAL::can($self,'fontfile'))
     {
-        foreach my $g (unpack('n*',$text)) {
+        foreach my $g (unpack('n*',$text)) 
+        {
             $self->fontfile->subsetByCId($g);
         }
     }
@@ -260,7 +281,7 @@ sub text_cid
 
 sub text_cid_kern 
 {
-    my ($self,$text,$size)=@_;
+    my ($self,$text,$size,$ident)=@_;
     if(UNIVERSAL::can($self,'fontfile'))
     {
         foreach my $g (unpack('n*',$text)) 
@@ -270,30 +291,44 @@ sub text_cid_kern
     }
     if(defined $size && $self->{-dokern} && $self->haveKernPairs())
     {
-            my $newtext=' ';
-            my $lastglyph=0;
-            my $tBefore=0;
-            foreach my $n (unpack('n*',$text)) 
+        my $newtext=' ';
+        my $lastglyph=0;
+        my $tBefore=0;
+        foreach my $n (unpack('n*',$text)) 
+        {
+            if($self->kernPairCid($lastglyph, $n))
             {
-                if($self->kernPairCid($lastglyph, $n))
-                {
-                    $newtext.='> ' if($tBefore);
-                    $newtext.=sprintf('%i ',$self->kernPairCid($lastglyph, $n));
-                    $tBefore=0;
-                }
-                $lastglyph=$n;
-                my $t=sprintf('%04X',$n);
-                $newtext.='<' if(!$tBefore);
-                $newtext.=$t;
-                $tBefore=1;
+                $newtext.='> ' if($tBefore);
+                $newtext.=sprintf('%i ',$self->kernPairCid($lastglyph, $n));
+                $tBefore=0;
             }
-            $newtext.='> ' if($tBefore);
+            $lastglyph=$n;
+            my $t=sprintf('%04X',$n);
+            $newtext.='<' if(!$tBefore);
+            $newtext.=$t;
+            $tBefore=1;
+        }
+        $newtext.='> ' if($tBefore);
+        if(defined($ident) && $ident!=0)
+        {
+	        return("[ $ident $newtext ] TJ");
+        }
+        else
+        {
             return("[ $newtext ] TJ");
+        }
     }
     elsif(defined $size)
     {
         my $newtext=unpack('H*',$text);
-        return("<$newtext> Tj");
+        if(defined($ident) && $ident!=0)
+        {
+	        return("[ $ident <$newtext> ] TJ");
+        }
+        else
+        {
+	        return("<$newtext> Tj");
+        }
     }
     else
     {
@@ -322,34 +357,36 @@ sub encodeByName
     $self->data->{e2g}=[ map { $self->data->{u2g}->{$_} || 0 } @{$self->data->{e2u}} ];
 
     $self->data->{u2e}={};
-    foreach my $n (reverse 0..255) {
+    foreach my $n (reverse 0..255) 
+    {
         $self->data->{u2e}->{$self->data->{e2u}->[$n]}=$n unless(defined $self->data->{u2e}->{$self->data->{e2u}->[$n]});
     }
 
     return($self);
 }
 
-sub kernPairCid {
-    return(0);
-}
-
-sub subsetByCId {
+sub subsetByCId 
+{
     return(1);
 }
 
-sub subvec {
+sub subvec 
+{
     return(1);
 }
 
-sub glyphNum { 
+sub glyphNum 
+{ 
     my $self=shift @_;
-    if(defined $self->data->{glyphs}) {
+    if(defined $self->data->{glyphs}) 
+    {
         return ( $self->data->{glyphs} ); 
     }
     return ( scalar @{$self->data->{wx}} ); 
 }
 
-sub outobjdeep {
+sub outobjdeep 
+{
     my ($self, $fh, $pdf, %opts) = @_;
 
     return $self->SUPER::outobjdeep($fh, $pdf) if defined $opts{'passthru'};
@@ -369,6 +406,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CIDFont.pm,v $
+    Revision 2.3  2007/03/17 20:38:50  areibens
+    replaced IOString dep. with scalar IO.
+
+    Revision 2.2  2007/01/04 16:02:28  areibens
+    applied untested fix for acrobat 8 "<ident> TJ" bug
+
+    Revision 2.1  2006/06/19 19:22:07  areibens
+    removed dup sub
+
     Revision 2.0  2005/11/16 02:16:04  areibens
     revision workaround for SF cvs import not to screw up CPAN
 
