@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: ColorSpace.pm,v 1.10 2005/06/17 18:53:34 fredo Exp $
+#   $Id: ColorSpace.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Array);
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,'$Revision: 1.10 $' =~ /Revision: (\S+)\s/); # $Date: 2005/06/17 18:53:34 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:04 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -135,6 +135,18 @@ alfred reibenschuh
 =head1
 
     $Log: ColorSpace.pm,v $
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
+    Revision 1.11  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
     Revision 1.10  2005/06/17 18:53:34  fredo
     fixed CPAN modulefile versioning (dislikes cvs)
 
