@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Indexed.pm,v 1.7 2004/12/16 00:30:53 fredo Exp $
+#   $Id: Indexed.pm,v 2.0 2005/11/16 02:18:14 areibens Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,7 @@ BEGIN {
     use Math::Trig;
 
     @ISA = qw( PDF::API2::Resource::ColorSpace );
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:18:14 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -122,6 +122,24 @@ __END__
 =head1 HISTORY
 
     $Log: Indexed.pm,v $
+    Revision 2.0  2005/11/16 02:18:14  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.10  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
+    Revision 1.9  2005/06/17 18:53:34  fredo
+    fixed CPAN modulefile versioning (dislikes cvs)
+
+    Revision 1.8  2005/03/14 22:01:27  fredo
+    upd 2005
+
     Revision 1.7  2004/12/16 00:30:53  fredo
     added no warn for recursion
 
