@@ -27,11 +27,12 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: courieroblique.pm,v 1.7 2005/06/07 23:21:39 fredo Exp $
+#   $Id: courieroblique.pm,v 2.0 2005/11/16 02:18:14 areibens Exp $
 #
 #=======================================================================
+package PDF::API2::Resource::Font::CoreFont::courieroblique;
 
-$fonts->{courieroblique}= {
+$FONTDATA = {
     'fontname' => 'Courier-Oblique',
     'type' => 'Type1',
     'apiname' => 'CoIt',
@@ -551,6 +552,18 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: courieroblique.pm,v $
+    Revision 2.0  2005/11/16 02:18:14  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:50  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:27  areibens
+    genesis
+
+    Revision 1.8  2005/09/12 16:56:21  fredo
+    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
+
     Revision 1.7  2005/06/07 23:21:39  fredo
     fontkey correction
 
